# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from mx_platform_python.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from mx_platform_python.model.account_number_response import AccountNumberResponse
from mx_platform_python.model.account_numbers_response_body import AccountNumbersResponseBody
from mx_platform_python.model.account_owner_response import AccountOwnerResponse
from mx_platform_python.model.account_owners_response_body import AccountOwnersResponseBody
from mx_platform_python.model.account_response import AccountResponse
from mx_platform_python.model.account_response_body import AccountResponseBody
from mx_platform_python.model.account_update_request import AccountUpdateRequest
from mx_platform_python.model.account_update_request_body import AccountUpdateRequestBody
from mx_platform_python.model.accounts_response_body import AccountsResponseBody
from mx_platform_python.model.categories_response_body import CategoriesResponseBody
from mx_platform_python.model.category_create_request import CategoryCreateRequest
from mx_platform_python.model.category_create_request_body import CategoryCreateRequestBody
from mx_platform_python.model.category_response import CategoryResponse
from mx_platform_python.model.category_response_body import CategoryResponseBody
from mx_platform_python.model.category_update_request import CategoryUpdateRequest
from mx_platform_python.model.category_update_request_body import CategoryUpdateRequestBody
from mx_platform_python.model.challenge_response import ChallengeResponse
from mx_platform_python.model.challenges_response_body import ChallengesResponseBody
from mx_platform_python.model.connect_widget_request import ConnectWidgetRequest
from mx_platform_python.model.connect_widget_request_body import ConnectWidgetRequestBody
from mx_platform_python.model.connect_widget_response import ConnectWidgetResponse
from mx_platform_python.model.connect_widget_response_body import ConnectWidgetResponseBody
from mx_platform_python.model.credential_request import CredentialRequest
from mx_platform_python.model.credential_response import CredentialResponse
from mx_platform_python.model.credentials_response_body import CredentialsResponseBody
from mx_platform_python.model.enhance_transaction_response import EnhanceTransactionResponse
from mx_platform_python.model.enhance_transactions_request import EnhanceTransactionsRequest
from mx_platform_python.model.enhance_transactions_request_body import EnhanceTransactionsRequestBody
from mx_platform_python.model.enhance_transactions_response_body import EnhanceTransactionsResponseBody
from mx_platform_python.model.holding_response import HoldingResponse
from mx_platform_python.model.holding_response_body import HoldingResponseBody
from mx_platform_python.model.holdings_response_body import HoldingsResponseBody
from mx_platform_python.model.image_option_response import ImageOptionResponse
from mx_platform_python.model.institution_response import InstitutionResponse
from mx_platform_python.model.institution_response_body import InstitutionResponseBody
from mx_platform_python.model.institutions_response_body import InstitutionsResponseBody
from mx_platform_python.model.managed_account_create_request import ManagedAccountCreateRequest
from mx_platform_python.model.managed_account_create_request_body import ManagedAccountCreateRequestBody
from mx_platform_python.model.managed_account_update_request import ManagedAccountUpdateRequest
from mx_platform_python.model.managed_account_update_request_body import ManagedAccountUpdateRequestBody
from mx_platform_python.model.managed_member_create_request import ManagedMemberCreateRequest
from mx_platform_python.model.managed_member_create_request_body import ManagedMemberCreateRequestBody
from mx_platform_python.model.managed_member_update_request import ManagedMemberUpdateRequest
from mx_platform_python.model.managed_member_update_request_body import ManagedMemberUpdateRequestBody
from mx_platform_python.model.managed_transaction_create_request import ManagedTransactionCreateRequest
from mx_platform_python.model.managed_transaction_create_request_body import ManagedTransactionCreateRequestBody
from mx_platform_python.model.managed_transaction_update_request import ManagedTransactionUpdateRequest
from mx_platform_python.model.managed_transaction_update_request_body import ManagedTransactionUpdateRequestBody
from mx_platform_python.model.member_create_request import MemberCreateRequest
from mx_platform_python.model.member_create_request_body import MemberCreateRequestBody
from mx_platform_python.model.member_response import MemberResponse
from mx_platform_python.model.member_response_body import MemberResponseBody
from mx_platform_python.model.member_resume_request import MemberResumeRequest
from mx_platform_python.model.member_resume_request_body import MemberResumeRequestBody
from mx_platform_python.model.member_status_response import MemberStatusResponse
from mx_platform_python.model.member_status_response_body import MemberStatusResponseBody
from mx_platform_python.model.member_update_request import MemberUpdateRequest
from mx_platform_python.model.member_update_request_body import MemberUpdateRequestBody
from mx_platform_python.model.members_response_body import MembersResponseBody
from mx_platform_python.model.merchant_location_response import MerchantLocationResponse
from mx_platform_python.model.merchant_location_response_body import MerchantLocationResponseBody
from mx_platform_python.model.merchant_response import MerchantResponse
from mx_platform_python.model.merchant_response_body import MerchantResponseBody
from mx_platform_python.model.merchants_response_body import MerchantsResponseBody
from mx_platform_python.model.o_auth_window_response import OAuthWindowResponse
from mx_platform_python.model.o_auth_window_response_body import OAuthWindowResponseBody
from mx_platform_python.model.option_response import OptionResponse
from mx_platform_python.model.pagination_response import PaginationResponse
from mx_platform_python.model.statement_response import StatementResponse
from mx_platform_python.model.statement_response_body import StatementResponseBody
from mx_platform_python.model.statements_response_body import StatementsResponseBody
from mx_platform_python.model.tag_create_request import TagCreateRequest
from mx_platform_python.model.tag_create_request_body import TagCreateRequestBody
from mx_platform_python.model.tag_response import TagResponse
from mx_platform_python.model.tag_response_body import TagResponseBody
from mx_platform_python.model.tag_update_request import TagUpdateRequest
from mx_platform_python.model.tag_update_request_body import TagUpdateRequestBody
from mx_platform_python.model.tagging_create_request import TaggingCreateRequest
from mx_platform_python.model.tagging_create_request_body import TaggingCreateRequestBody
from mx_platform_python.model.tagging_response import TaggingResponse
from mx_platform_python.model.tagging_response_body import TaggingResponseBody
from mx_platform_python.model.tagging_update_request import TaggingUpdateRequest
from mx_platform_python.model.tagging_update_request_body import TaggingUpdateRequestBody
from mx_platform_python.model.taggings_response_body import TaggingsResponseBody
from mx_platform_python.model.tags_response_body import TagsResponseBody
from mx_platform_python.model.transaction_response import TransactionResponse
from mx_platform_python.model.transaction_response_body import TransactionResponseBody
from mx_platform_python.model.transaction_rule_create_request import TransactionRuleCreateRequest
from mx_platform_python.model.transaction_rule_create_request_body import TransactionRuleCreateRequestBody
from mx_platform_python.model.transaction_rule_response import TransactionRuleResponse
from mx_platform_python.model.transaction_rule_response_body import TransactionRuleResponseBody
from mx_platform_python.model.transaction_rule_update_request import TransactionRuleUpdateRequest
from mx_platform_python.model.transaction_rule_update_request_body import TransactionRuleUpdateRequestBody
from mx_platform_python.model.transaction_rules_response_body import TransactionRulesResponseBody
from mx_platform_python.model.transaction_update_request import TransactionUpdateRequest
from mx_platform_python.model.transaction_update_request_body import TransactionUpdateRequestBody
from mx_platform_python.model.transactions_response_body import TransactionsResponseBody
from mx_platform_python.model.user_create_request import UserCreateRequest
from mx_platform_python.model.user_create_request_body import UserCreateRequestBody
from mx_platform_python.model.user_response import UserResponse
from mx_platform_python.model.user_response_body import UserResponseBody
from mx_platform_python.model.user_update_request import UserUpdateRequest
from mx_platform_python.model.user_update_request_body import UserUpdateRequestBody
from mx_platform_python.model.users_response_body import UsersResponseBody
from mx_platform_python.model.widget_request import WidgetRequest
from mx_platform_python.model.widget_request_body import WidgetRequestBody
from mx_platform_python.model.widget_response import WidgetResponse
from mx_platform_python.model.widget_response_body import WidgetResponseBody



"""
    MX Platform API

    The MX Platform API is a powerful, fully-featured API designed to make aggregating and enhancing financial data easy and reliable. It can seamlessly connect your app or website to tens of thousands of financial institutions.  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import mx_platform_python
from mx_platform_python.api.mx_platform_api import MxPlatformApi  # noqa: E501


class TestMxPlatformApi(unittest.TestCase):
    """MxPlatformApi unit test stubs"""

    def setUp(self):
        self.api = MxPlatformApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_aggregate_member(self):
        """Test case for aggregate_member

        Aggregate member  # noqa: E501
        """
        pass

    def test_check_balances(self):
        """Test case for check_balances

        Check balances  # noqa: E501
        """
        pass

    def test_create_category(self):
        """Test case for create_category

        Create category  # noqa: E501
        """
        pass

    def test_create_managed_account(self):
        """Test case for create_managed_account

        Create managed account  # noqa: E501
        """
        pass

    def test_create_managed_member(self):
        """Test case for create_managed_member

        Create managed member  # noqa: E501
        """
        pass

    def test_create_managed_transaction(self):
        """Test case for create_managed_transaction

        Create managed transaction  # noqa: E501
        """
        pass

    def test_create_member(self):
        """Test case for create_member

        Create member  # noqa: E501
        """
        pass

    def test_create_tag(self):
        """Test case for create_tag

        Create tag  # noqa: E501
        """
        pass

    def test_create_tagging(self):
        """Test case for create_tagging

        Create tagging  # noqa: E501
        """
        pass

    def test_create_transaction_rule(self):
        """Test case for create_transaction_rule

        Create transaction rule  # noqa: E501
        """
        pass

    def test_create_user(self):
        """Test case for create_user

        Create user  # noqa: E501
        """
        pass

    def test_delete_category(self):
        """Test case for delete_category

        Delete category  # noqa: E501
        """
        pass

    def test_delete_managed_account(self):
        """Test case for delete_managed_account

        Delete managed account  # noqa: E501
        """
        pass

    def test_delete_managed_member(self):
        """Test case for delete_managed_member

        Delete managed member  # noqa: E501
        """
        pass

    def test_delete_managed_transaction(self):
        """Test case for delete_managed_transaction

        Delete managed transaction  # noqa: E501
        """
        pass

    def test_delete_member(self):
        """Test case for delete_member

        Delete member  # noqa: E501
        """
        pass

    def test_delete_tag(self):
        """Test case for delete_tag

        Delete tag  # noqa: E501
        """
        pass

    def test_delete_tagging(self):
        """Test case for delete_tagging

        Delete tagging  # noqa: E501
        """
        pass

    def test_delete_transaction_rule(self):
        """Test case for delete_transaction_rule

        Delete transaction rule  # noqa: E501
        """
        pass

    def test_delete_user(self):
        """Test case for delete_user

        Delete user  # noqa: E501
        """
        pass

    def test_download_statement_pdf(self):
        """Test case for download_statement_pdf

        Download statement pdf  # noqa: E501
        """
        pass

    def test_enhance_transactions(self):
        """Test case for enhance_transactions

        Enhance transactions  # noqa: E501
        """
        pass

    def test_extend_history(self):
        """Test case for extend_history

        Extend history  # noqa: E501
        """
        pass

    def test_fetch_statements(self):
        """Test case for fetch_statements

        Fetch statements  # noqa: E501
        """
        pass

    def test_identify_member(self):
        """Test case for identify_member

        Identify member  # noqa: E501
        """
        pass

    def test_list_account_numbers_by_account(self):
        """Test case for list_account_numbers_by_account

        List account numbers by account  # noqa: E501
        """
        pass

    def test_list_account_numbers_by_member(self):
        """Test case for list_account_numbers_by_member

        List account numbers by member  # noqa: E501
        """
        pass

    def test_list_account_owners_by_member(self):
        """Test case for list_account_owners_by_member

        List account owners by member  # noqa: E501
        """
        pass

    def test_list_categories(self):
        """Test case for list_categories

        List categories  # noqa: E501
        """
        pass

    def test_list_default_categories(self):
        """Test case for list_default_categories

        List default categories  # noqa: E501
        """
        pass

    def test_list_default_categories_by_user(self):
        """Test case for list_default_categories_by_user

        List default categories by user  # noqa: E501
        """
        pass

    def test_list_favorite_institutions(self):
        """Test case for list_favorite_institutions

        List favorite institutions  # noqa: E501
        """
        pass

    def test_list_holdings(self):
        """Test case for list_holdings

        List holdings  # noqa: E501
        """
        pass

    def test_list_holdings_by_account(self):
        """Test case for list_holdings_by_account

        List holdings by account  # noqa: E501
        """
        pass

    def test_list_holdings_by_member(self):
        """Test case for list_holdings_by_member

        List holdings by member  # noqa: E501
        """
        pass

    def test_list_institution_credentials(self):
        """Test case for list_institution_credentials

        List institution credentials  # noqa: E501
        """
        pass

    def test_list_institutions(self):
        """Test case for list_institutions

        List institutions  # noqa: E501
        """
        pass

    def test_list_managed_accounts(self):
        """Test case for list_managed_accounts

        List managed accounts  # noqa: E501
        """
        pass

    def test_list_managed_institutions(self):
        """Test case for list_managed_institutions

        List managed institutions  # noqa: E501
        """
        pass

    def test_list_managed_members(self):
        """Test case for list_managed_members

        List managed members  # noqa: E501
        """
        pass

    def test_list_managed_transactions(self):
        """Test case for list_managed_transactions

        List managed transactions  # noqa: E501
        """
        pass

    def test_list_member_challenges(self):
        """Test case for list_member_challenges

        List member challenges  # noqa: E501
        """
        pass

    def test_list_member_credentials(self):
        """Test case for list_member_credentials

        List member credentials  # noqa: E501
        """
        pass

    def test_list_members(self):
        """Test case for list_members

        List members  # noqa: E501
        """
        pass

    def test_list_merchants(self):
        """Test case for list_merchants

        List merchants  # noqa: E501
        """
        pass

    def test_list_statements_by_member(self):
        """Test case for list_statements_by_member

        List statements by member  # noqa: E501
        """
        pass

    def test_list_taggings(self):
        """Test case for list_taggings

        List taggings  # noqa: E501
        """
        pass

    def test_list_tags(self):
        """Test case for list_tags

        List tags  # noqa: E501
        """
        pass

    def test_list_transaction_rules(self):
        """Test case for list_transaction_rules

        List transaction rules  # noqa: E501
        """
        pass

    def test_list_transactions(self):
        """Test case for list_transactions

        List transactions  # noqa: E501
        """
        pass

    def test_list_transactions_by_account(self):
        """Test case for list_transactions_by_account

        List transactions by account  # noqa: E501
        """
        pass

    def test_list_transactions_by_member(self):
        """Test case for list_transactions_by_member

        List transactions by member  # noqa: E501
        """
        pass

    def test_list_transactions_by_tag(self):
        """Test case for list_transactions_by_tag

        List transactions by tag  # noqa: E501
        """
        pass

    def test_list_user_accounts(self):
        """Test case for list_user_accounts

        List accounts  # noqa: E501
        """
        pass

    def test_list_users(self):
        """Test case for list_users

        List users  # noqa: E501
        """
        pass

    def test_read_account(self):
        """Test case for read_account

        Read account  # noqa: E501
        """
        pass

    def test_read_category(self):
        """Test case for read_category

        Read a custom category  # noqa: E501
        """
        pass

    def test_read_default_category(self):
        """Test case for read_default_category

        Read a default category  # noqa: E501
        """
        pass

    def test_read_holding(self):
        """Test case for read_holding

        Read holding  # noqa: E501
        """
        pass

    def test_read_institution(self):
        """Test case for read_institution

        Read institution  # noqa: E501
        """
        pass

    def test_read_managed_account(self):
        """Test case for read_managed_account

        Read managed account  # noqa: E501
        """
        pass

    def test_read_managed_member(self):
        """Test case for read_managed_member

        Read managed member  # noqa: E501
        """
        pass

    def test_read_managed_transaction(self):
        """Test case for read_managed_transaction

        Read managed transaction  # noqa: E501
        """
        pass

    def test_read_member(self):
        """Test case for read_member

        Read member  # noqa: E501
        """
        pass

    def test_read_member_status(self):
        """Test case for read_member_status

        Read member status  # noqa: E501
        """
        pass

    def test_read_merchant(self):
        """Test case for read_merchant

        Read merchant  # noqa: E501
        """
        pass

    def test_read_merchant_location(self):
        """Test case for read_merchant_location

        Read merchant location  # noqa: E501
        """
        pass

    def test_read_statement_by_member(self):
        """Test case for read_statement_by_member

        Read statement by member  # noqa: E501
        """
        pass

    def test_read_tag(self):
        """Test case for read_tag

        Read tag  # noqa: E501
        """
        pass

    def test_read_tagging(self):
        """Test case for read_tagging

        Read tagging  # noqa: E501
        """
        pass

    def test_read_transaction(self):
        """Test case for read_transaction

        Read transaction  # noqa: E501
        """
        pass

    def test_read_transaction_rule(self):
        """Test case for read_transaction_rule

        Read transaction rule  # noqa: E501
        """
        pass

    def test_read_user(self):
        """Test case for read_user

        Read user  # noqa: E501
        """
        pass

    def test_request_connect_widget_url(self):
        """Test case for request_connect_widget_url

        Request connect widget url  # noqa: E501
        """
        pass

    def test_request_o_auth_window_uri(self):
        """Test case for request_o_auth_window_uri

        Request oauth window uri  # noqa: E501
        """
        pass

    def test_request_widget_url(self):
        """Test case for request_widget_url

        Request widget url  # noqa: E501
        """
        pass

    def test_resume_aggregation(self):
        """Test case for resume_aggregation

        Resume aggregation  # noqa: E501
        """
        pass

    def test_update_account_by_member(self):
        """Test case for update_account_by_member

        Update account by member  # noqa: E501
        """
        pass

    def test_update_category(self):
        """Test case for update_category

        Update category  # noqa: E501
        """
        pass

    def test_update_managed_account(self):
        """Test case for update_managed_account

        Update managed account  # noqa: E501
        """
        pass

    def test_update_managed_member(self):
        """Test case for update_managed_member

        Update managed member  # noqa: E501
        """
        pass

    def test_update_managed_transaction(self):
        """Test case for update_managed_transaction

        Update managed transaction  # noqa: E501
        """
        pass

    def test_update_member(self):
        """Test case for update_member

        Update member  # noqa: E501
        """
        pass

    def test_update_tag(self):
        """Test case for update_tag

        Update tag  # noqa: E501
        """
        pass

    def test_update_tagging(self):
        """Test case for update_tagging

        Update tagging  # noqa: E501
        """
        pass

    def test_update_transaction(self):
        """Test case for update_transaction

        Update transaction  # noqa: E501
        """
        pass

    def test_update_transaction_rule(self):
        """Test case for update_transaction_rule

        Update transaction_rule  # noqa: E501
        """
        pass

    def test_update_user(self):
        """Test case for update_user

        Update user  # noqa: E501
        """
        pass

    def test_verify_member(self):
        """Test case for verify_member

        Verify member  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

"""
    MX Platform API

    The MX Platform API is a powerful, fully-featured API designed to make aggregating and enhancing financial data easy and reliable. It can seamlessly connect your app or website to tens of thousands of financial institutions.  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


__version__ = "0.9.2"

# import ApiClient
from mx_platform_python.api_client import ApiClient

# import Configuration
from mx_platform_python.configuration import Configuration

# import exceptions
from mx_platform_python.exceptions import OpenApiException
from mx_platform_python.exceptions import ApiAttributeError
from mx_platform_python.exceptions import ApiTypeError
from mx_platform_python.exceptions import ApiValueError
from mx_platform_python.exceptions import ApiKeyError
from mx_platform_python.exceptions import ApiException



"""
    MX Platform API

    The MX Platform API is a powerful, fully-featured API designed to make aggregating and enhancing financial data easy and reliable. It can seamlessly connect your app or website to tens of thousands of financial institutions.  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import mx_platform_python
from mx_platform_python.model.tagging_create_request import TaggingCreateRequest


class TestTaggingCreateRequest(unittest.TestCase):
    """TaggingCreateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTaggingCreateRequest(self):
        """Test TaggingCreateRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = TaggingCreateRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    MX Platform API

    The MX Platform API is a powerful, fully-featured API designed to make aggregating and enhancing financial data easy and reliable. It can seamlessly connect your app or website to tens of thousands of financial institutions.  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "mx-platform-python"
VERSION = "0.9.2"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
  "urllib3 >= 1.25.3",
  "python-dateutil",
]

setup(
    name=NAME,
    version=VERSION,
    description="MX Platform API",
    author="MX Platform API",
    author_email="team@openapitools.org",
    url="https://pypi.org/project/mx-platform-python",
    keywords=["OpenAPI", "OpenAPI-Generator", "MX Platform API"],
    python_requires=">=3.6",
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description="""\
    The MX Platform API is a powerful, fully-featured API designed to make aggregating and enhancing financial data easy and reliable. It can seamlessly connect your app or website to tens of thousands of financial institutions.  # noqa: E501
    """
)
